summaryrefslogtreecommitdiffstats
path: root/webapp/config/index.js
diff options
context:
space:
mode:
Diffstat (limited to 'webapp/config/index.js')
-rw-r--r--webapp/config/index.js6
1 files changed, 5 insertions, 1 deletions
diff --git a/webapp/config/index.js b/webapp/config/index.js
index e283935..c1ed721 100644
--- a/webapp/config/index.js
+++ b/webapp/config/index.js
@@ -42,9 +42,13 @@ module.exports = {
cssSourceMap: true,
proxyTable: {
// proxy all requests starting with /api to express server
'/api': {
target: 'https://localhost:' + process.env.API_PORT + '/'
+ },
+ '/socket.io': {
+ target: 'https://localhost:' + process.env.API_PORT + '/',
+ ws: true
}
}
},
@@ -42,9 +42,13 @@ module.exports = {
cssSourceMap: true,
proxyTable: {
- // proxy all requests starting with /api to express server
+ // proxy all requests starting with /api and /socket.io to the express server
'/api': {
target: 'https://localhost:' + process.env.API_PORT + '/'